@@ -26,13 +26,23 @@
 #include "gth-metadata-provider-comment.h"
 
 
-G_DEFINE_TYPE (GthMetadataProviderComment, gth_metadata_provider_comment, GTH_TYPE_METADATA_PROVIDER)
+struct _GthMetadataProviderCommentPrivate {
+	GHashTable *checked_folders;
+};
+
+
+G_DEFINE_TYPE_WITH_CODE (GthMetadataProviderComment,
+			 gth_metadata_provider_comment,
+			 GTH_TYPE_METADATA_PROVIDER,
+			 G_ADD_PRIVATE (GthMetadataProviderComment))
 
 
 static gboolean
-gth_metadata_provider_comment_can_read (GthMetadataProvider  *self,
-				        const char           *mime_type,
-				        char                **attribute_v)
+gth_metadata_provider_comment_can_read (GthMetadataProvider  *base,
+					GthFileData          *file_data,
+					const char           *mime_type,
+					char                **attribute_v)
+
 {
 	return _g_file_attributes_matches_any_v ("comment::*,"
 						 "general::datetime,"
@@ -41,7 +51,7 @@ gth_metadata_provider_comment_can_read (GthMetadataProvider  *self,
 						 "general::location,"
 						 "general::tags,"
 						 "general::rating",
-					         attribute_v);
+						 attribute_v);
 }
 
 
@@ -62,7 +72,7 @@ gth_metadata_provider_comment_can_write (GthMetadataProvider  *self,
 
 
 static void
-gth_metadata_provider_comment_read (GthMetadataProvider *self,
+gth_metadata_provider_comment_read (GthMetadataProvider *base,
 				    GthFileData         *file_data,
 				    const char          *attributes,
 				    GCancellable        *cancellable)
@@ -72,6 +82,30 @@ gth_metadata_provider_comment_read (GthMetadataProvider *self,
 	GPtrArray  *categories;
 	char       *comment_time;
 
+	// Check if the .comment directory exists
+	GFile *comment_file = gth_comment_get_comment_file (file_data->file);
+	if (comment_file != NULL) {
+		GFile *comment_folder = g_file_get_parent (comment_file);
+		if (comment_folder != NULL) {
+			GthMetadataProviderComment *self = GTH_METADATA_PROVIDER_COMMENT (base);
+			gpointer value = g_hash_table_lookup (self->priv->checked_folders, comment_folder);
+			gboolean comment_folder_exists;
+			if (value == NULL) {
+				comment_folder_exists = g_file_query_exists (comment_folder, NULL);
+				g_hash_table_insert (self->priv->checked_folders,
+					g_object_ref (comment_folder),
+					GINT_TO_POINTER (comment_folder_exists ? 1 : 2));
+			}
+			else {
+				comment_folder_exists = GPOINTER_TO_INT (value) == 1;
+			}
+			if (!comment_folder_exists) {
+				g_file_info_set_attribute_boolean (file_data->info, "comment::no-comment-file", TRUE);
+				return;
+			}
+		}
+	}
+
 	comment = gth_comment_new_for_file (file_data->file, cancellable, NULL);
 	g_file_info_set_attribute_boolean (file_data->info, "comment::no-comment-file", (comment == NULL));
 
@@ -127,7 +161,21 @@ gth_metadata_provider_comment_read (GthMetadataProvider *self,
 	else
 		g_file_info_remove_attribute (file_data->info, "comment::time");
 
-	gth_comment_update_general_attributes (file_data);
+	// Update the general attributes if the comment file is not older
+	// than the image file or the attributes were not updated from the
+	// embedded data.
+	gboolean update_general_attributes = TRUE;
+	if (g_file_info_has_attribute (file_data->info, "embedded::updated-general-attributes")) {
+		if (g_file_info_get_attribute_boolean (file_data->info, "embedded::updated-general-attributes")) {
+			GDateTime *file_modification_time = g_file_info_get_modification_date_time (file_data->info);
+			if (gth_comment_file_is_older (comment, file_modification_time)) {
+				update_general_attributes = FALSE;
+			}
+		}
+	}
+	if (update_general_attributes) {
+		gth_comment_update_general_attributes (file_data);
+	}
 
 	g_object_unref (comment);
 }
@@ -220,20 +268,53 @@ gth_metadata_provider_comment_write (GthMetadataProvider   *self,
 }
 
 
+static int
+gth_metadata_provider_comment_get_priority (GthMetadataProvider *self)
+{
+	// Lower than exiv2, and other embedded metadata readers, to make
+	// sure the comment reader is executed after all other readers.
+	return 20;
+}
+
+
+static void
+gth_metadata_provider_comment_finalize (GObject *object)
+{
+	GthMetadataProviderComment *self;
+
+	g_return_if_fail (object != NULL);
+	g_return_if_fail (GTH_IS_METADATA_PROVIDER_COMMENT (object));
+
+	self = GTH_METADATA_PROVIDER_COMMENT (object);
+	g_hash_table_unref (self->priv->checked_folders);
+
+	/* Chain up */
+	G_OBJECT_CLASS (gth_metadata_provider_comment_parent_class)->finalize (object);
+}
+
+
 static void
 gth_metadata_provider_comment_class_init (GthMetadataProviderCommentClass *klass)
+
 {
+	GObjectClass             *gobject_class;
 	GthMetadataProviderClass *mp_class;
 
+	gobject_class = G_OBJECT_CLASS (klass);
+	gobject_class->finalize = gth_metadata_provider_comment_finalize;
+
 	mp_class = GTH_METADATA_PROVIDER_CLASS (klass);
 	mp_class->can_read = gth_metadata_provider_comment_can_read;
 	mp_class->can_write = gth_metadata_provider_comment_can_write;
 	mp_class->read = gth_metadata_provider_comment_read;
 	mp_class->write = gth_metadata_provider_comment_write;
+	mp_class->get_priority = gth_metadata_provider_comment_get_priority;
 }
 
+
 static void
 gth_metadata_provider_comment_init (GthMetadataProviderComment *self)
 {
-	/* void */
+	self->priv = gth_metadata_provider_comment_get_instance_private (self);
+	self->priv->checked_folders = g_hash_table_new_full (g_file_hash, (GEqualFunc) g_file_equal, g_object_unref, NULL);
 }
