@@ -287,6 +287,7 @@ gth_file_tool_effects_destroy_options (GthFileTool *base)
 	_cairo_clear_surface (&self->priv->destination);
 	self->priv->method = GTH_FILTER_GRID_NO_FILTER;
 	self->priv->last_applied_method = GTH_FILTER_GRID_NO_FILTER;
+	self->priv->view_original = TRUE;
 }
 
 
@@ -351,7 +352,7 @@ gth_file_tool_effects_init (GthFileToolEffects *self)
 	self->priv->builder = NULL;
 	self->priv->method = GTH_FILTER_GRID_NO_FILTER;
 	self->priv->last_applied_method = GTH_FILTER_GRID_NO_FILTER;
-	self->priv->view_original = FALSE;
+	self->priv->view_original = TRUE;
 
 	gth_file_tool_construct (GTH_FILE_TOOL (self),
 				 "special-effects-symbolic",
