@@ -426,6 +426,7 @@ gth_file_tool_grayscale_destroy_options (GthFileTool *base)
 	_cairo_clear_surface (&self->priv->destination);
 	self->priv->method = GTH_FILTER_GRID_NO_FILTER;
 	self->priv->last_applied_method = GTH_FILTER_GRID_NO_FILTER;
+	self->priv->view_original = TRUE;
 }
 
 
@@ -490,7 +491,7 @@ gth_file_tool_grayscale_init (GthFileToolGrayscale *self)
 	self->priv->builder = NULL;
 	self->priv->method = GTH_FILTER_GRID_NO_FILTER;
 	self->priv->last_applied_method = GTH_FILTER_GRID_NO_FILTER;
-	self->priv->view_original = FALSE;
+	self->priv->view_original = TRUE;
 
 	gth_file_tool_construct (GTH_FILE_TOOL (self),
 				 "image-grayscale-symbolic",
