@@ -27,10 +27,14 @@
 DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_in)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_out)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_100)
+DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_200)
+DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_300)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_fit)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_fit_if_larger)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_fit_width)
+DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_fit_width_if_larger)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_fit_height)
+DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom_fit_height_if_larger)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_undo)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_redo)
 DEF_ACTION_CALLBACK (gth_browser_activate_copy_image)
@@ -39,5 +43,15 @@ DEF_ACTION_CALLBACK (gth_browser_activate_apply_icc_profile)
 DEF_ACTION_CALLBACK (gth_browser_activate_image_zoom)
 DEF_ACTION_CALLBACK (gth_browser_activate_toggle_animation)
 DEF_ACTION_CALLBACK (gth_browser_activate_step_animation)
+DEF_ACTION_CALLBACK (gth_browser_activate_transparency_style)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_step_left)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_step_right)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_step_up)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_step_down)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_page_left)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_page_right)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_page_up)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_page_down)
+DEF_ACTION_CALLBACK (gth_browser_activate_scroll_to_center)
 
 #endif /* ACTIONS_H */
