@@ -34,7 +34,7 @@
 #include "gtk-utils.h"
 
 
-#define RESTART_LOADING_THUMBS_DELAY 1500
+#define RESTART_LOADING_THUMBS_DELAY 500
 #define N_CREATEAHEAD 50000
 #define MAX_THUMBNAIL_LOADERS 4
 #define MAX_THUMBNAILS_TO_CHECK 25
@@ -411,8 +411,11 @@ restart_thumb_update_cb (gpointer data)
 	GthFileList *file_list = data;
 
 	file_list->priv->restart_thumb_update = 0;
-	if (! file_list->priv->cancelling)
+	if (! file_list->priv->cancelling) {
+		// Restart
+		file_list->priv->thumbnailer_state.phase = THUMBNAILER_PHASE_INITIALIZE;
 		_gth_file_list_update_next_thumb (file_list);
+	}
 
 	return G_SOURCE_REMOVE;
 }
@@ -1536,6 +1539,9 @@ _gth_file_list_thumbnailer_iterate (GthFileList *file_list,
 			if (! _thumbnail_loaded (state)
 			    && can_create_file_thumbnail (file_data, current_time, young_file_found))
 			{
+#ifdef DEBUG_THUMBNAILER
+			g_print ("    UPDATE!\n");
+#endif
 				/* found a thumbnail to load */
 				g_object_unref (file_data);
 				return FALSE;
@@ -1781,6 +1787,12 @@ _gth_file_list_update_next_thumb (GthFileList *file_list)
 			/* void */;
 
 		if (file_list->priv->thumbnailer_state.phase == THUMBNAILER_PHASE_COMPLETED) {
+#ifdef DEBUG_THUMBNAILER
+			g_print ("  PHASE: COMPLETED\n");
+			if (young_file_found) {
+				g_print ("  YOUNG FILE FOUND\n");
+			}
+#endif
 			_gth_file_list_thumbs_completed (file_list);
 			if (young_file_found) {
 				if (file_list->priv->restart_thumb_update != 0)
