@@ -831,8 +831,7 @@ base_rename (GthFileSource *file_source,
 
 
 static gboolean
-base_can_cut (GthFileSource *file_source,
-	      GFile         *file)
+base_can_cut (GthFileSource *file_source)
 {
 	return FALSE;
 }
@@ -901,6 +900,15 @@ base_shows_extra_widget (GthFileSource *file_source)
 }
 
 
+static GdkDragAction
+base_get_drop_actions (GthFileSource *file_source,
+		       GFile         *destination,
+		       GFile         *file)
+{
+	return 0; /* no action supported by default. */
+}
+
+
 static void
 gth_file_source_finalize (GObject *object)
 {
@@ -939,6 +947,7 @@ gth_file_source_class_init (GthFileSourceClass *class)
 	class->deleted_from_disk = base_deleted_from_disk;
 	class->get_free_space = base_get_free_space;
 	class->shows_extra_widget = base_shows_extra_widget;
+	class->get_drop_actions = base_get_drop_actions;
 }
 
 
@@ -965,19 +974,16 @@ gboolean
 gth_file_source_supports_scheme (GthFileSource *file_source,
 				 const char    *uri)
 {
-	gboolean  result = FALSE;
-	GList    *scan;
+	GList *scan;
 
 	for (scan = file_source->priv->schemes; scan; scan = scan->next) {
 		const char *scheme = scan->data;
 
-		if (strncmp (uri, scheme, strlen (scheme)) == 0) {
-			result = TRUE;
-			break;
-		}
+		if (g_str_has_prefix (uri, scheme))
+			return TRUE;
 	}
 
-	return result;
+	return FALSE;
 }
 
 
@@ -1335,10 +1341,9 @@ gth_file_source_copy (GthFileSource    *file_source,
 
 
 gboolean
-gth_file_source_can_cut (GthFileSource *file_source,
-			 GFile         *file)
+gth_file_source_can_cut (GthFileSource *file_source)
 {
-	return GTH_FILE_SOURCE_GET_CLASS (G_OBJECT (file_source))->can_cut (file_source, file);
+	return GTH_FILE_SOURCE_GET_CLASS (G_OBJECT (file_source))->can_cut (file_source);
 }
 
 
@@ -1438,3 +1443,12 @@ gth_file_source_shows_extra_widget (GthFileSource *file_source)
 {
 	return GTH_FILE_SOURCE_GET_CLASS (G_OBJECT (file_source))->shows_extra_widget (file_source);
 }
+
+
+GdkDragAction
+gth_file_source_get_drop_actions (GthFileSource *file_source,
+				  GFile         *destination,
+				  GFile         *file)
+{
+	return GTH_FILE_SOURCE_GET_CLASS (G_OBJECT (file_source))->get_drop_actions (file_source, destination, file);
+}
