@@ -99,6 +99,7 @@ static GthMain *Main = NULL;
 struct _GthMainPrivate {
 	GList               *file_sources;
 	GList               *metadata_provider;
+	gboolean             metadata_provider_sorted;
 	GPtrArray           *metadata_category;
 	GPtrArray           *metadata_info;
 	GHashTable          *metadata_info_hash;
@@ -181,6 +182,7 @@ gth_main_init (GthMain *main)
 	main->priv = gth_main_get_instance_private (main);
 	main->priv->file_sources = NULL;
 	main->priv->metadata_provider = NULL;
+	main->priv->metadata_provider_sorted = FALSE;
 	main->priv->metadata_category = g_ptr_array_new ();
 	main->priv->metadata_info = g_ptr_array_new ();
 	main->priv->metadata_info_hash = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
@@ -485,9 +487,33 @@ gth_main_register_metadata_provider (GType metadata_provider_type)
 }
 
 
+static int metadata_provider_sort_func (gconstpointer a, gconstpointer b)
+{
+	GthMetadataProvider *provider_a = (GthMetadataProvider *) a;
+	GthMetadataProvider *provider_b = (GthMetadataProvider *) b;
+	int priority_a = gth_metadata_provider_get_priority (provider_a);
+	int priority_b = gth_metadata_provider_get_priority (provider_b);
+	if (priority_a == priority_b) {
+		return 0;
+	}
+	else if (priority_a < priority_b) {
+		return -1;
+	}
+	else {
+		return 1;
+	}
+}
+
+
 GList *
 gth_main_get_all_metadata_providers (void)
 {
+	g_mutex_lock (&register_mutex);
+	if (!Main->priv->metadata_provider_sorted) {
+		Main->priv->metadata_provider = g_list_sort (Main->priv->metadata_provider, metadata_provider_sort_func);
+		Main->priv->metadata_provider_sorted = TRUE;
+	}
+	g_mutex_unlock (&register_mutex);
 	return Main->priv->metadata_provider;
 }
 
@@ -1368,16 +1394,14 @@ gth_main_activate_extensions (void)
 {
 	const char *mandatory_extensions[] = {
 		"file_viewer", /* keep the file viewer before any other viewer (see comment in gth-browser:file_metadata_ready_cb). */
-#ifdef HAVE_LIBJPEG
-		"jpeg_utils",  /* mandatory if jpeg support is activated at compile time */
-#endif
+		"jpeg_utils",
+		"exiv2_tools",
 		"cairo_io",
 		"image_viewer",
 		"file_tools",
 		NULL
 	};
 	const char *default_extensions[] = {
-		"23hq",
 		"bookmarks",
 		"burn_disc",
 		"catalogs",
@@ -1387,10 +1411,9 @@ gth_main_activate_extensions (void)
 		"convert_format",
 		"desktop_background",
 		"edit_metadata",
-		"exiv2_tools",
+		"open_map",
 		"file_manager",
 		"find_duplicates",
-		"flicker",
 		"gstreamer_tools",
 		"gstreamer_utils",
 		"image_print",
@@ -1398,7 +1421,6 @@ gth_main_activate_extensions (void)
 		"importer",
 		"jpeg_utils",
 		"list_tools",
-		"oauth",
 		"photo_importer",
 		"raw_files",
 		"red_eye_removal",
@@ -1443,7 +1465,7 @@ gth_main_activate_extensions (void)
 
 		mandatory = _g_strv_contains ((char **) mandatory_extensions, name);
 		description = gth_extension_manager_get_description (manager, name);
-		if (! mandatory && (description != NULL) && description->hidden)
+		if (! mandatory && ((description == NULL) || description->hidden))
 			continue;
 
 		if (! gth_extension_manager_activate (Main->priv->extension_manager, name, &error)) {
@@ -1451,8 +1473,9 @@ gth_main_activate_extensions (void)
 				g_critical ("Could not load the mandatory extension '%s': %s", name, error->message);
 				abort ();
 			}
-			else
+			else {
 				g_warning ("Could not load the '%s' extension: %s", name, error->message);
+			}
 			g_clear_error (&error);
 		}
 	}
