@@ -29,8 +29,8 @@
 #include "gtk-utils.h"
 
 
-#define EXPANDED_LIST_HEIGHT 160
-#define POPUP_WINDOW_HEIGHT 250
+#define EXPANDED_LIST_WIDTH 500
+#define EXPANDED_LIST_HEIGHT 300
 
 
 enum {
@@ -51,8 +51,8 @@ enum {
 
 /* Properties */
 enum {
-        PROP_0,
-        PROP_MODE
+	PROP_0,
+	PROP_MODE
 };
 
 /* Signals */
@@ -81,20 +81,12 @@ typedef struct  {
 } ExpandedList;
 
 
-typedef struct {
-	GtkWidget *window;
-	GtkWidget *container;
-	GdkDevice *grab_pointer;
-	GdkDevice *grab_keyboard;
-} PopupWindow;
-
-
 struct _GthTagsEntryPrivate {
 	GthTagsEntryMode	  mode;
 	GtkWidget		 *entry;
 	GtkWidget		 *expand_button;
 	ExpandedList		  expanded_list;
-	PopupWindow               popup;
+	GtkWidget		 *popover;
 	gboolean		  expanded;
 	char			**tags;
 	GtkEntryCompletion	 *completion;
@@ -109,7 +101,10 @@ struct _GthTagsEntryPrivate {
 static guint signals[LAST_SIGNAL] = { 0 };
 
 
-G_DEFINE_TYPE (GthTagsEntry, gth_tags_entry, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_CODE (GthTagsEntry,
+			 gth_tags_entry,
+			 GTK_TYPE_BOX,
+			 G_ADD_PRIVATE (GthTagsEntry))
 
 
 static void
@@ -126,7 +121,6 @@ gth_tags_entry_finalize (GObject *obj)
 	g_strfreev (self->priv->tags);
 	g_strfreev (self->priv->expanded_list.last_used);
 	gtk_widget_destroy (self->priv->expanded_list.popup_menu);
-	gtk_widget_destroy (self->priv->popup.window);
 	g_hash_table_unref (self->priv->inconsistent);
 
 	G_OBJECT_CLASS (gth_tags_entry_parent_class)->finalize (obj);
@@ -156,7 +150,7 @@ gth_tags_entry_set_property (GObject      *object,
 			gtk_container_remove (GTK_CONTAINER (gtk_widget_get_parent (self->priv->expanded_list.scrolled_window)), self->priv->expanded_list.scrolled_window);
 
 			if (self->priv->mode == GTH_TAGS_ENTRY_MODE_POPUP)
-				gtk_box_pack_start (GTK_BOX (self->priv->popup.container), self->priv->expanded_list.scrolled_window, TRUE, TRUE, 0);
+				gtk_container_add (GTK_CONTAINER (self->priv->popover), self->priv->expanded_list.scrolled_window);
 			else
 				gtk_box_pack_start (GTK_BOX (self->priv->expanded_list.container), self->priv->expanded_list.scrolled_window, TRUE, TRUE, 0);
 
@@ -206,8 +200,6 @@ gth_tags_entry_class_init (GthTagsEntryClass *klass)
 	GObjectClass   *object_class;
 	GtkWidgetClass *widget_class;
 
-	g_type_class_add_private (klass, sizeof (GthTagsEntryPrivate));
-
 	object_class = (GObjectClass*) (klass);
 	object_class->set_property = gth_tags_entry_set_property;
 	object_class->get_property = gth_tags_entry_get_property;
@@ -337,7 +329,7 @@ update_expanded_list_from_entry (GthTagsEntry *self)
 	char        **all_tags;
 	char        **used_tags;
 	TagData     **tag_data;
-	int           i, t;
+	int           i, t, tag_data_len;
 	GtkTreeIter   iter;
 	gboolean      separator_required;
 
@@ -372,9 +364,10 @@ update_expanded_list_from_entry (GthTagsEntry *self)
 
 		t++;
 	}
+	tag_data_len = t - 1;
 
 	g_qsort_with_data (tag_data,
-			   g_strv_length (tag_data),
+			   tag_data_len,
 			   sizeof (TagData *),
 			   sort_tag_data,
 			   NULL);
@@ -769,10 +762,12 @@ cell_renderer_toggle_toggled_cb (GtkCellRendererToggle *cell_renderer,
 
 
 static void
-tag_list_unmap_cb (GtkWidget    *widget,
-		   GthTagsEntry *self)
+popover_closed_cb (GtkPopover *popover,
+		   gpointer    user_data)
 {
-        g_signal_emit (self, signals[LIST_COLLAPSED], 0);
+	GthTagsEntry *self = user_data;
+	g_signal_emit (self, signals[LIST_COLLAPSED], 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->expand_button), FALSE);
 }
 
 
@@ -850,229 +845,13 @@ expanded_list_button_press_event_cb (GtkStatusIcon  *status_icon,
 {
 	GthTagsEntry *self = user_data;
 
-	if (event->button == 3) {
-		gtk_menu_popup (GTK_MENU (self->priv->expanded_list.popup_menu),
-				NULL,
-				NULL,
-				NULL,
-				NULL,
-				event->button,
-				event->time);
-		return FALSE;
-	}
+	if (event->button == 3)
+		gtk_menu_popup_at_pointer (GTK_MENU (self->priv->expanded_list.popup_menu), (GdkEvent *) event);
 
 	return FALSE;
 }
 
 
-/* -- popup window -- */
-
-
-static void
-_gth_tags_entry_ungrab_devices (GthTagsEntry *self,
-				guint32       time)
-{
-	if (self->priv->popup.grab_pointer != NULL) {
-		gdk_device_ungrab (self->priv->popup.grab_pointer, time);
-		gtk_device_grab_remove (self->priv->popup.window, self->priv->popup.grab_pointer);
-		self->priv->popup.grab_pointer = NULL;
-	}
-
-	if (self->priv->popup.grab_keyboard != NULL) {
-		gdk_device_ungrab (self->priv->popup.grab_keyboard, time);
-		self->priv->popup.grab_keyboard = NULL;
-	}
-}
-
-
-static gboolean
-_gth_tags_entry_grab_broken_event (GtkWidget          *widget,
-				   GdkEventGrabBroken *event,
-				   gpointer            user_data)
-{
-	GthTagsEntry *self = user_data;
-
-	if (event->grab_window == NULL)
-		_gth_tags_entry_ungrab_devices (self, GDK_CURRENT_TIME);
-
-	return TRUE;
-}
-
-
-static void
-popup_window_hide (GthTagsEntry *self)
-{
-	_gth_tags_entry_ungrab_devices (self, GDK_CURRENT_TIME);
-
-	self->priv->expanded = FALSE;
-	gtk_widget_hide (self->priv->popup.window);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->expand_button), FALSE);
-}
-
-
-static gboolean
-popup_window_button_press_event_cb (GtkWidget      *widget,
-				    GdkEventButton *event,
-				    gpointer        user_data)
-{
-	GthTagsEntry		 *self = user_data;
-	cairo_rectangle_int_t	  popup_area;
-
-	gdk_window_get_geometry (gtk_widget_get_window (self->priv->popup.window),
-				 &popup_area.x,
-				 &popup_area.y,
-				 &popup_area.width,
-				 &popup_area.height);
-
-	/*g_print ("(%.0f, %.0f) <==> (%d, %d)[%d, %d]\n", event->x_root, event->y_root,  popup_area.x,  popup_area.y, popup_area.width, popup_area.height);*/
-
-	if ((event->x_root < popup_area.x)
-	    || (event->x_root > popup_area.x + popup_area.width)
-	    || (event->y_root < popup_area.y)
-	    || (event->y_root > popup_area.y + popup_area.height))
-	{
-		popup_window_hide (self);
-	}
-
-	return FALSE;
-}
-
-
-static gboolean
-popup_window_key_press_event_cb (GtkWidget   *widget,
-				 GdkEventKey *event,
-				 gpointer     user_data)
-{
-	GthTagsEntry *self = user_data;
-
-	switch (event->keyval) {
-	case GDK_KEY_Escape:
-		popup_window_hide (self);
-		break;
-
-	default:
-		break;
-	}
-
-	return FALSE;
-}
-
-
-static gboolean
-_gth_tags_entry_grab_devices (GdkWindow	*window,
-			      GdkDevice	*keyboard,
-			      GdkDevice	*pointer,
-			      GdkCursor	*cursor,
-			      guint32	 time)
-{
-	if (keyboard != NULL) {
-		if (gdk_device_grab (keyboard,
-				     window,
-				     GDK_OWNERSHIP_APPLICATION,
-				     TRUE,
-				     (GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK),
-				     NULL,
-				     time) != GDK_GRAB_SUCCESS)
-		{
-			return FALSE;
-		}
-	}
-
-	if (pointer != NULL) {
-		if (gdk_device_grab (pointer,
-				     window,
-				     GDK_OWNERSHIP_APPLICATION,
-				     TRUE,
-				     GDK_ALL_EVENTS_MASK,
-				     cursor,
-				     time) != GDK_GRAB_SUCCESS)
-		{
-			if (keyboard != NULL)
-				gdk_device_ungrab (keyboard, time);
-
-			return FALSE;
-		}
-	}
-
-	return TRUE;
-}
-
-
-static void
-popup_window_show (GthTagsEntry *self)
-{
-	GtkRequisition         popup_req;
-	int                    x;
-	int                    y;
-	GtkAllocation          allocation;
-	int                    selector_height;
-	GdkRectangle           monitor;
-	GdkDevice             *device;
-	GdkDevice             *pointer;
-	GdkDevice             *keyboard;
-
-	gdk_window_get_position (gtk_widget_get_window (GTK_WIDGET (self)), &x, &y);
-	gtk_widget_get_allocation (self->priv->entry, &allocation);
-	x += allocation.x;
-	y += allocation.y;
-	selector_height = allocation.height;
-
-	gtk_widget_get_allocation (GTK_WIDGET (self), &allocation);
-	popup_req.width = allocation.width;
-	popup_req.height = POPUP_WINDOW_HEIGHT;
-
-	_gtk_widget_get_monitor_geometry (GTK_WIDGET (self), &monitor);
-	if (x < monitor.x)
-		x = monitor.x;
-	else if (x + popup_req.width > monitor.x + monitor.width)
-		x = monitor.x + monitor.width - popup_req.width;
-	if (y + selector_height + popup_req.height > monitor.y + monitor.height)
-		y = y - popup_req.height;
-	else
-		y = y + selector_height;
-
-	gtk_window_resize (GTK_WINDOW (self->priv->popup.window), popup_req.width, popup_req.height);
-	gtk_window_move (GTK_WINDOW (self->priv->popup.window), x, y);
-	gtk_widget_show (self->priv->popup.window);
-
-	device = gtk_get_current_event_device ();
-	if (device == NULL) {
-		GdkDeviceManager *device_manager;
-		GdkDisplay	 *display;
-		GList		 *devices;
-
-		display = gtk_widget_get_display (GTK_WIDGET (self));
-		device_manager = gdk_display_get_device_manager (display);
-		devices = gdk_device_manager_list_devices (device_manager, GDK_DEVICE_TYPE_MASTER);
-		device = devices->data;
-
-		g_list_free (devices);
-	}
-
-	if (gdk_device_get_source (device) == GDK_SOURCE_KEYBOARD) {
-		keyboard = device;
-		pointer = gdk_device_get_associated_device (device);
-	}
-	else {
-		pointer = device;
-		keyboard = gdk_device_get_associated_device (device);
-	}
-
-	gtk_widget_grab_focus (self->priv->expanded_list.tree_view);
-
-	if (_gth_tags_entry_grab_devices (gtk_widget_get_window (self->priv->popup.window),
-					  keyboard,
-					  pointer,
-					  NULL,
-					  GDK_CURRENT_TIME))
-	{
-		self->priv->popup.grab_pointer = pointer;
-		self->priv->popup.grab_keyboard = keyboard;
-		gtk_device_grab_add (self->priv->popup.window, self->priv->popup.grab_pointer, TRUE);
-	}
-}
-
-
 static void
 expand_button_toggled_cb (GtkToggleButton *button,
 			  gpointer         user_data)
@@ -1085,12 +864,14 @@ expand_button_toggled_cb (GtkToggleButton *button,
 			gtk_widget_show (self->priv->expanded_list.container);
 			break;
 		case GTH_TAGS_ENTRY_MODE_POPUP:
-			popup_window_show (self);
+			gtk_popover_popup (GTK_POPOVER (self->priv->popover));
 			break;
 		}
 	}
-	else
-		gtk_widget_hide (self->priv->expanded_list.container);
+	else {
+		gtk_popover_popdown (GTK_POPOVER (self->priv->popover));
+		//gtk_widget_hide (self->priv->expanded_list.container);
+	}
 }
 
 
@@ -1117,13 +898,11 @@ gth_tags_entry_init (GthTagsEntry *self)
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_VERTICAL);
 	gtk_box_set_spacing (GTK_BOX (self), 3);
 
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_TAGS_ENTRY, GthTagsEntryPrivate);
+	self->priv = gth_tags_entry_get_instance_private (self);
 	self->priv->mode = GTH_TAGS_ENTRY_MODE_INLINE;
 	self->priv->expanded_list.last_used = g_new0 (char *, 1);
 	self->priv->expanded = FALSE;
 	self->priv->inconsistent = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
-	self->priv->popup.grab_pointer = NULL;
-	self->priv->popup.grab_keyboard = NULL;
 
 	/* entry / expander button box */
 
@@ -1166,7 +945,7 @@ gth_tags_entry_init (GthTagsEntry *self)
 
 	self->priv->expand_button = gtk_toggle_button_new ();
 	gtk_widget_set_tooltip_text (self->priv->expand_button, _("Show all the tags"));
-	gtk_container_add (GTK_CONTAINER (self->priv->expand_button), gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE));
+	gtk_container_add (GTK_CONTAINER (self->priv->expand_button), gtk_image_new_from_icon_name ("go-down-symbolic", GTK_ICON_SIZE_BUTTON));
 	gtk_widget_show_all (self->priv->expand_button);
 	gtk_box_pack_start (GTK_BOX (hbox), self->priv->expand_button, FALSE, FALSE, 0);
 
@@ -1231,21 +1010,13 @@ gth_tags_entry_init (GthTagsEntry *self)
 	gtk_widget_show (menu_item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (self->priv->expanded_list.popup_menu), menu_item);
 
-	/* popup window */
+	/* popover */
 
-	self->priv->popup.window = gtk_window_new (GTK_WINDOW_POPUP);
-	g_signal_connect (self->priv->popup.window,
-			  "button-press-event",
-			  G_CALLBACK (popup_window_button_press_event_cb),
+	self->priv->popover = gtk_popover_new (self->priv->expand_button);
+	g_signal_connect (self->priv->popover,
+			  "closed",
+			  G_CALLBACK (popover_closed_cb),
 			  self);
-	g_signal_connect (self->priv->popup.window,
-			  "key-press-event",
-			  G_CALLBACK (popup_window_key_press_event_cb),
-			  self);
-
-	self->priv->popup.container = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	gtk_widget_show (self->priv->popup.container);
-	gtk_container_add (GTK_CONTAINER (self->priv->popup.window), self->priv->popup.container);
 
 	/**/
 
@@ -1259,7 +1030,7 @@ gth_tags_entry_init (GthTagsEntry *self)
 							    "vscrollbar_policy", GTK_POLICY_AUTOMATIC,
 							    "shadow_type", GTK_SHADOW_IN,
 							    NULL);
-	gtk_widget_set_size_request (self->priv->expanded_list.scrolled_window, -1, EXPANDED_LIST_HEIGHT);
+	gtk_widget_set_size_request (self->priv->expanded_list.scrolled_window, EXPANDED_LIST_WIDTH, EXPANDED_LIST_HEIGHT);
 	gtk_box_pack_start (GTK_BOX (self->priv->expanded_list.container),
 			    self->priv->expanded_list.scrolled_window,
 			    TRUE,
@@ -1269,11 +1040,6 @@ gth_tags_entry_init (GthTagsEntry *self)
 			   self->priv->expanded_list.tree_view);
 	gtk_widget_show_all (self->priv->expanded_list.scrolled_window);
 
-	g_signal_connect (self->priv->expanded_list.scrolled_window,
-			  "unmap",
-			  G_CALLBACK (tag_list_unmap_cb),
-			  self);
-
 	self->priv->monitor_event = g_signal_connect (gth_main_get_default_monitor (),
 						      "tags-changed",
 						      G_CALLBACK (tags_changed_cb),
@@ -1290,10 +1056,6 @@ gth_tags_entry_init (GthTagsEntry *self)
 			  "button-press-event",
 			  G_CALLBACK (expanded_list_button_press_event_cb),
 			  self);
-	g_signal_connect (self,
-			  "grab-broken-event",
-			  G_CALLBACK (_gth_tags_entry_grab_broken_event),
-			  self);
 
 	/**/
 
@@ -1325,7 +1087,7 @@ gth_tags_entry_set_list_visible (GthTagsEntry *self,
 		break;
 
 	case GTH_TAGS_ENTRY_MODE_POPUP:
-		popup_window_show (self);
+		gtk_popover_popup (GTK_POPOVER (self->priv->popover));
 		break;
 	}
 }
