@@ -24,6 +24,7 @@
 
 #include <gtk/gtk.h>
 #include "gth-file-data.h"
+#include "typedefs.h"
 
 G_BEGIN_DECLS
 
@@ -57,6 +58,7 @@ struct _GthViewerPageInterface {
 	void      (*view)                (GthViewerPage *self,
 				 	  GthFileData   *file_data);
 	void      (*focus)               (GthViewerPage *self);
+	gboolean  (*has_focus)           (GthViewerPage *self);
 	void      (*fullscreen)          (GthViewerPage *self,
 					  gboolean       active);
 	void      (*show_pointer)        (GthViewerPage *self,
@@ -75,6 +77,15 @@ struct _GthViewerPageInterface {
 					  GthFileData   *file_data);
 	void      (*show_properties)     (GthViewerPage *self,
 					  gboolean       show);
+	gboolean  (*zoom_from_scroll)    (GthViewerPage *self,
+					  GdkEventScroll *event);
+
+	const char * (*shortcut_context) (GthViewerPage *self);
+	gboolean  (*can_open_clipboard)  (GthViewerPage *self,
+					  GdkAtom      *atoms,
+					  int           n_atoms);
+	void      (*open_clipboard)      (GthViewerPage *self,
+					  GtkClipboard  *clipboard);
 
 	/*< signals >*/
 
@@ -94,6 +105,7 @@ gboolean     gth_viewer_page_can_view            (GthViewerPage  *self,
 void         gth_viewer_page_view                (GthViewerPage  *self,
 						  GthFileData    *file_data);
 void         gth_viewer_page_focus               (GthViewerPage  *self);
+gboolean     gth_viewer_page_has_focus           (GthViewerPage  *self);
 void         gth_viewer_page_fullscreen          (GthViewerPage  *self,
 						  gboolean       active);
 void         gth_viewer_page_show_pointer        (GthViewerPage  *self,
@@ -112,9 +124,19 @@ void         gth_viewer_page_update_info         (GthViewerPage  *self,
 		  	  	  	  	  GthFileData    *file_data);
 void         gth_viewer_page_show_properties     (GthViewerPage  *self,
 						  gboolean        show);
+gboolean     gth_viewer_page_zoom_from_scroll    (GthViewerPage  *self,
+						  GdkEventScroll *event);
 void         gth_viewer_page_file_loaded         (GthViewerPage  *self,
 						  GthFileData    *file_data,
+						  GFileInfo      *updated_metadata,
 						  gboolean        success);
+const char * gth_viewer_page_get_shortcut_context
+						 (GthViewerPage  *self);
+gboolean     gth_viewer_page_can_open_clipboard  (GthViewerPage  *self,
+						  GdkAtom        *atoms,
+						  int             n_atoms);
+void         gth_viewer_page_open_clipboard      (GthViewerPage  *self,
+						  GtkClipboard   *clipboard);
 
 G_END_DECLS
 
